@@ -13,12 +13,14 @@ def _parse_axis(data_shape, axis):
     axis = 0 if axis == "time" else axis
     if (axis == "spatial") or (axis == "space"):
         if len(data_shape) == 1:
-            ValueError(f"axis '{axis}' not allowed for Dataset with shape {data_shape}")
+            raise ValueError(
+                f"axis '{axis}' not allowed for Dataset with shape {data_shape}"
+            )
         axis = 1 if (len(data_shape) == 2) else tuple(range(1, len(data_shape)))
     if axis is None:
         axis = 0 if (len(data_shape) == 1) else tuple(range(0, len(data_shape)))
     if isinstance(axis, str):
-        ValueError(
+        raise ValueError(
             f"axis argument '{axis}' not supported! Must be None, int, list of int or 'time' or 'space'"
         )
     return axis
@@ -183,7 +185,7 @@ class Dataset(TimeSeries):
             data = self.create_empty_data(
                 n_items=n_items, n_timesteps=n_timesteps, n_elements=n_elements
             )
-        elif isinstance(data, Sequence):
+        elif isinstance(data, Sequence) and hasattr(data[0], "shape"):
             n_items = len(data)
             n_timesteps = data[0].shape[0]
         else:
@@ -314,7 +316,7 @@ class Dataset(TimeSeries):
 
     def __mul__(self, other):
         if isinstance(other, self.__class__):
-            raise NotImplemented("Multiplication is not implemented for two Datasets")
+            raise ValueError("Multiplication is not possible for two Datasets")
         else:
             return self._multiply_value(other)
 
@@ -386,7 +388,7 @@ class Dataset(TimeSeries):
 
     def to_numpy(self):
         """Stack data to a single ndarray with shape (n_items, n_timesteps, ...)
-        
+
         Returns
         -------
         np.ndarray
@@ -460,14 +462,23 @@ class Dataset(TimeSeries):
             return self._append_items(other, copy=True)
 
     def _append_items(self, other, copy=True):
+
+        item_names = self._non_z_item_names
+        other_names = other._non_z_item_names
+
+        overlap = other_names.intersection(item_names)
+        if len(overlap) != 0:
+            raise ValueError("Can not append items, names are not unique")
+
         if not np.all(self.time == other.time):
             # if not: create common time?
             raise ValueError("All timesteps must match")
         ds = self.copy() if copy else self
 
         for j in range(other.n_items):
-            ds.items.append(other.items[j])
-            ds.data.append(other.data[j])
+            if other.items[j].name != "Z coordinate":  #
+                ds.items.append(other.items[j])
+                ds.data.append(other.data[j])
         return ds
 
     def concat(self, other, inplace=False):
@@ -506,8 +517,8 @@ class Dataset(TimeSeries):
 
     def _concat_time(self, other, copy=True):
         self._check_all_items_match(other)
-        if not np.all(self.shape == other.shape):
-            raise ValueError("Shape of the datasets must match")
+        if not np.all(self.shape[1:] == other.shape[1:]):
+            raise ValueError("Shape of the datasets must match (except time dimension)")
         ds = self.copy() if copy else self
 
         s1 = pd.Series(np.arange(len(ds.time)), index=ds.time, name="idx1")
@@ -803,7 +814,7 @@ class Dataset(TimeSeries):
         >>> dfs = Dfsu("HD2D.dfsu")
         >>> ds = dfs.read(["Current speed"])
         >>> area = dfs.get_element_area()
-        >>> ds2 = ds.average(weights=area)
+        >>> ds2 = ds.average(axis="space", weights=area)
         """
 
         def func(x, axis, keepdims):
@@ -1039,92 +1050,12 @@ class Dataset(TimeSeries):
             data.append(dati)
         return data
 
-    @staticmethod
-    def create_time(start_time=None, dt=None, n_timesteps=None, end_time=None):
-        """Deprecated: use `pandas.date_range` instead
-
-        Parameters
-        ----------
-        start_time : datetime or str, optional
-            start_time, by default None (1970-1-1 00:00:00)
-            can optionally contain end_time e.g. '2018-01-01, 2018-02-01'
-        dt : float, optional
-            time step in seconds, by default None
-        n_timesteps : int, optional
-            number of timesteps, by default 1
-        end_time : datetime or str, optional
-            end_time, by default 3600s or deduced from other parameters
-
-        Returns
-        -------
-        pandas.DatetimeIndex
-            time axis which can be used to create new Dataset
-
-        Examples
-        ------
-        >>> t = Dateset.create_time('2018-1-1,2018-2-1', dt=1800)
-        >>> t = Dateset.create_time('2018-1-1', dt=1800, n_timesteps=48)
-        >>> t = Dateset.create_time('2018', dt=7200, end_time='2019')
-        """
-
-        warnings.warn(
-            "Dataset.create_time is deprecated, please use `pandas.date_range` instead.",
-            FutureWarning,
-        )
-
-        if isinstance(start_time, str):
-            parts = start_time.split(",")
-            if len(parts) == 2:
-                end_time = parts[1]
-            start_time = pd.to_datetime(parts[0])
-        if isinstance(end_time, str):
-            end_time = pd.to_datetime(end_time)
-
-        if start_time is None:
-            # start_time = datetime.now()
-            start_time = datetime(1970, 1, 1, 0, 0, 0)
-
-        if dt is None:
-            if (end_time is not None) and (n_timesteps is not None):
-                dur = (end_time - start_time).total_seconds()
-                dt = 0.0
-                if (dur > 0) and (n_timesteps > 1):
-                    dt = dur / (n_timesteps - 1)
-            else:
-                warnings.warn("Too little information. Assuming dt=3600s.")
-                dt = 3600
-
-        if (end_time is None) and (n_timesteps is None):
-            warnings.warn("Too little information. Assuming n_timesteps=1.")
-            n_timesteps = 1
-
-        # find end time
-        if end_time is None:
-            tot_seconds = (n_timesteps - 1) * dt
-            end_time = start_time + timedelta(seconds=tot_seconds)
-        elif (end_time is not None) and (n_timesteps is not None):
-            # both are given, do they match?
-            tot_seconds = (n_timesteps - 1) * dt
-            end_time_2 = start_time + timedelta(seconds=tot_seconds)
-            if end_time != end_time_2:
-                raise ValueError("All parameters where given, but they do not match")
-
-        if dt < 0:
-            raise ValueError("dt cannot be negative")
-
-        if (end_time - start_time).total_seconds() < 0:
-            raise ValueError("end_time must be greater than start_time")
-
-        offset = pd.tseries.offsets.DateOffset(seconds=dt)
-        return pd.date_range(start=start_time, end=end_time, freq=offset)
-
     @property
     def is_equidistant(self):
         """Is Dataset equidistant in time?"""
         if len(self.time) < 3:
             return True
         return len(self.time.to_series().diff().dropna().unique()) == 1
-        # return self.time.freq is not None
 
     @property
     def start_time(self):
@@ -1172,6 +1103,11 @@ class Dataset(TimeSeries):
             return 1
         return 0
 
+    @property
+    def _non_z_item_names(self):
+        """Item names (Z coordinate excluded)"""
+        return {item.name for item in self.items[self._first_non_z_item :]}
+
     @property
     def n_elements(self):
         """Number of spatial elements/points"""
