@@ -37,6 +37,17 @@ def ds2():
     return Dataset(data, time, items)
 
 
+def test_create_wrong_data_type_error():
+
+    data = ["item 1", "item 2"]
+
+    nt = 2
+    time = pd.date_range(start=datetime(2000, 1, 1), freq="S", periods=nt)
+
+    with pytest.raises(TypeError, match="numpy"):
+        Dataset(data=data, time=time)
+
+
 def test_get_names():
 
     data = []
@@ -76,6 +87,18 @@ def test_select_subset_isel():
     assert selds["Bar"][0, 0] == 3.0
 
 
+def test_select_subset_isel_axis_out_of_range_error(ds2):
+
+    assert len(ds2.shape) == 2
+    dss = ds2.isel(idx=0)
+
+    # After subsetting there is only one dimension
+    assert len(dss.shape) == 1
+
+    with pytest.raises(ValueError):
+        dss.isel(idx=0, axis="spatial")
+
+
 def test_select_temporal_subset_by_idx():
 
     nt = 100
@@ -480,9 +503,16 @@ def test_set_data_name():
     assert ds["Foo"][0, 0] == 0.0
 
     ds["Foo"] = np.zeros((nt, 10)) + 1.0
-
     assert ds["Foo"][0, 0] == 1.0
 
+    ds[0] = np.zeros((nt, 10)) + 2.0  # Set using position
+    assert ds["Foo"][0, 0] == 2.0  # Read using name
+
+    with pytest.raises(ValueError):
+        ds[[0, 1]] = (
+            np.zeros((nt, 10)) + 2.0
+        )  # You can't set data for several items (at least not yet)
+
 
 def test_get_bad_name():
     nt = 100
@@ -614,7 +644,7 @@ def test_aggregation_workflows(tmpdir):
     assert os.path.isfile(outfilename)
 
 
-def test_aggregations(tmpdir):
+def test_aggregations():
     filename = "tests/testdata/gebco_sound.dfs2"
     dfs = Dfs2(filename)
 
@@ -630,6 +660,11 @@ def test_aggregations(tmpdir):
     assert ds.mean(axis=(1, 2)).shape == (1,)
     assert ds.mean(axis=(0, 1)).shape == (1, 216)
     assert ds.mean(axis=(0, 2)).shape == (1, 264)
+    assert ds.mean(axis="spatial").shape == (1,)
+    assert ds.mean(axis="space").shape == (1,)
+
+    with pytest.raises(ValueError, match="space"):
+        ds.mean(axis="spaghetti")
 
 
 def test_weighted_average(tmpdir):
@@ -961,6 +996,31 @@ def test_add_scalar(ds1):
     assert np.all(ds3[1] == ds2[1])
 
 
+def test_add_inconsistent_dataset(ds1):
+
+    ds2 = ds1[[0]]
+
+    assert len(ds1) != len(ds2)
+
+    with pytest.raises(ValueError):
+        ds1 + ds2
+
+    with pytest.raises(ValueError):
+        ds1 * ds2
+
+
+def test_add_bad_value(ds1):
+
+    with pytest.raises(ValueError):
+        ds1 + ["one"]
+
+
+def test_multiple_bad_value(ds1):
+
+    with pytest.raises(ValueError):
+        ds1 * ["pi"]
+
+
 def test_sub_scalar(ds1):
     ds2 = ds1 - 10.0
     assert np.all(ds1[0] - ds2[0] == 10.0)
@@ -1026,7 +1086,7 @@ def test_non_equidistant():
     assert not ds.is_equidistant
 
 
-def test_combine():
+def test_combine_by_time():
     ds1 = mikeio.read("tests/testdata/tide1.dfs1")
     ds2 = mikeio.read("tests/testdata/tide2.dfs1") + 0.5  # add offset
     ds3 = Dataset.combine(ds1, ds2)
@@ -1034,7 +1094,11 @@ def test_combine():
     assert isinstance(ds3, Dataset)
     assert len(ds1) == len(ds2) == len(ds3)
     assert ds3.start_time == ds1.start_time
+    assert ds3.start_time < ds2.start_time
     assert ds3.end_time == ds2.end_time
+    assert ds3.end_time > ds1.end_time
+    assert ds3.n_timesteps == 145
+    assert ds3.is_equidistant
 
     ds4 = Dataset.combine([ds1, ds2])
 
@@ -1042,3 +1106,100 @@ def test_combine():
     assert len(ds1) == len(ds2) == len(ds4)
     assert ds4.start_time == ds1.start_time
     assert ds4.end_time == ds2.end_time
+
+
+def test_combine_by_time_2():
+    ds1 = mikeio.read("tests/testdata/tide1.dfs1", time_steps=range(0, 12))
+    ds2 = mikeio.read("tests/testdata/tide2.dfs1")
+    ds3 = Dataset.combine(ds1, ds2)
+
+    assert ds3.n_timesteps == 109
+    assert not ds3.is_equidistant
+
+    # create combined datasets in 8 chunks of 6 hours
+    dsall = []
+    for j in range(8):
+        dsall.append(
+            mikeio.read(
+                "tests/testdata/tide1.dfs1", time_steps=range(j * 12, 1 + (j + 1) * 12)
+            )
+        )
+    ds4 = Dataset.combine(*dsall)
+    assert len(dsall) == 8
+    assert ds4.n_timesteps == 97
+    assert ds4.is_equidistant
+
+
+def test_combine_by_item():
+    ds1 = mikeio.read("tests/testdata/tide1.dfs1")
+    ds2 = mikeio.read("tests/testdata/tide1.dfs1")
+    ds2.items[0].name = ds2.items[0].name + " v2"
+    ds3 = Dataset.combine(ds1, ds2)
+
+    assert isinstance(ds3, Dataset)
+    assert ds3.n_items == 2
+    assert ds3.items[1].name == ds1.items[0].name + " v2"
+
+
+def test_combine_by_item_dfsu_3d():
+    ds1 = mikeio.read("tests/testdata/oresund_sigma_z.dfsu", items=[0, 1])
+    assert ds1.n_items == 2
+    ds2 = mikeio.read("tests/testdata/oresund_sigma_z.dfsu", items=[0, 2])
+    assert ds2.n_items == 2
+
+    ds3 = Dataset.combine(ds1, ds2)
+
+    assert isinstance(ds3, Dataset)
+    itemnames = [x.name for x in ds3.items]
+    assert "Salinity" in itemnames
+    assert "Temperature" in itemnames
+    assert ds3.n_items == 3  # Only one instance of Z coordinate
+
+
+def test_to_numpy(ds2):
+
+    X = ds2.to_numpy()
+
+    assert X.shape == (ds2.n_items,) + ds2.shape
+    assert isinstance(X, np.ndarray)
+
+
+def test_concat():
+    filename = "tests/testdata/HD2D.dfsu"
+    ds1 = mikeio.read(filename, time_steps=[0, 1])
+    ds2 = mikeio.read(filename, time_steps=[2, 3])
+    ds3 = ds1.concat(ds2)
+    ds3.n_timesteps
+
+    assert ds1.n_items == ds2.n_items == ds3.n_items
+    assert ds3.n_timesteps == (ds1.n_timesteps + ds2.n_timesteps)
+    assert ds3.start_time == ds1.start_time
+    assert ds3.end_time == ds2.end_time
+
+
+def test_append_items():
+    filename = "tests/testdata/HD2D.dfsu"
+    ds1 = mikeio.read(filename, items=0)
+    ds2 = mikeio.read(filename, items=1)
+
+    assert ds1.n_items == 1
+    assert ds2.n_items == 1
+    ds3 = ds1.append_items(ds2)
+    assert ds1.n_items == 1
+    assert ds2.n_items == 1
+    assert ds3.n_items == 2
+
+    ds1.append_items(ds2, inplace=True)
+
+    assert ds1.n_items == 2
+
+
+def test_append_items_same_name_error():
+    filename = "tests/testdata/HD2D.dfsu"
+    ds1 = mikeio.read(filename, items=0)
+    ds2 = mikeio.read(filename, items=0)
+
+    assert ds1.items[0].name == ds2.items[0].name
+
+    with pytest.raises(ValueError):
+        ds1.append_items(ds2)
